function Test-DynamicParameter
{
  [CmdletBinding()]

  param
  (
    [Parameter(Mandatory=$true)]
    [ValidateSet('FirmaA','FirmaB','FirmaC','FirmaD')]
    # Name der Firma, erlaubt sind nur die im ValidateSet angegebenen
    # Firmennamen 'FirmaA','FirmaB','FirmaC' und 'FirmaD'
    $Firma
  )

  dynamicparam
  {
    # der zweite (dynamische) Parameter -Abteilung wird nur eingeblendet,
    # wenn bereits mit -Firma eine Firma ausgewhlt wurde

    # hier stehen fr jede Firma die gltigen Werte, die fr
    # -Abteilung angegeben werden drfen:
    $data = @{
      FirmaA = 'Geschftsfhrung', 'Marketing', 'Vertrieb'
      FirmaB = 'Marketing', 'Vertrieb'
      FirmaC = 'Geschftsfhrung', 'Auendienst', 'Fuhrpark'
      FirmaD = 'Geschftsfhrung', 'Gebudemanagement', 'Fuhrpark'
    }

    # wurde bereits die Firma mit -Firma angegeben?
    if ($Firma)
    {
      # ja, also dynamischen Parameter anlegen:
      $paramDictionary = New-Object -TypeName System.Management.Automation.RuntimeDefinedParameterDictionary
      $attributeCollection = New-Object -TypeName System.Collections.ObjectModel.Collection[System.Attribute]

      # Parameter-Attribute festsetzen:
      $attribute = New-Object System.Management.Automation.ParameterAttribute
      $attribute.ParameterSetName = '__AllParameterSets'
      $attribute.Mandatory = $false
      $attributeCollection.Add($attribute)

      # gltige Werte festsetzen;
      # die gltigen Abteilungsnamen fr eine Firma stehen im Hashtable $data
      # $data.$firma liefert also die Liste der fr die jeweilige Firma gltigen
      # Abteilungsnamen.
      # Diese werden als ValidateSet dynamisch dem Parameter hinzugefgt:
      $attribute = New-Object System.Management.Automation.ValidateSetAttribute($data.$firma)
      $attributeCollection.Add($attribute)

      # dynamischen Parameter -Abteilung anlegen:
      $Name = 'Abteilung'
      $dynParam = New-Object -TypeName System.Management.Automation.RuntimeDefinedParameter($Name,
        [string], $attributeCollection)
      $paramDictionary.Add($Name, $dynParam)

      # Parameter zurckgeben:
      $paramDictionary
    }
  }

  end
  {
    'Die bergebenen Parameter:'
    $PSBoundParameters
  }
}

